@@ -38,10 +38,10 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static final String java_version =
-        "20.0.2";
+        "22.0.1";
 
     private static final String java_version_date =
-        "2023-07-18";
+        "2024-04-16";
 
     // This field is read by HotSpot
     private static final String java_runtime_name =
@@ -49,16 +49,16 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static final String java_runtime_version =
-        "20.0.2+9";
+        "22.0.1+8";
 
     private static final String VERSION_NUMBER =
-        "20.0.2";
+        "22.0.1";
 
     private static final String VERSION_SPECIFICATION =
-        "20";
+        "22";
 
     private static final String VERSION_BUILD =
-        "9";
+        "8";
 
     private static final String VERSION_PRE =
         "";
@@ -70,10 +70,10 @@ class VersionProps {
         "".startsWith("LTS");
 
     private static final String CLASSFILE_MAJOR_MINOR =
-        "64.0";
+        "66.0";
 
     private static final String VENDOR =
-        "N/A";
+        "Arch Linux";
 
     private static final String VENDOR_URL =
         "https://openjdk.org/";
